import { useState, useEffect } from "react";
import { useLocation, useSearch } from "wouter";
import { useQuery } from "@tanstack/react-query";
import SearchBar from "@/components/listing/SearchBar";
import ListingGrid from "@/components/listing/ListingGrid";
import Pagination from "@/components/common/Pagination";
import { SORT_OPTIONS } from "@/lib/constants";
import { 
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";

interface Listing {
  id: number;
  title: string;
  price: number | null;
  description: string;
  location: string;
  createdAt: string;
  isUrgent?: boolean;
  primaryImage?: string | null;
  userId: number;
}

const ITEMS_PER_PAGE = 12;

const SearchResults = () => {
  const [, navigate] = useLocation();
  const search = useSearch();
  const searchParams = new URLSearchParams(search);
  
  // Get search parameters
  const query = searchParams.get("q") || "";
  const locationParam = searchParams.get("location") || "";
  const categoryParam = searchParams.get("category") || "";
  const minPrice = searchParams.get("minPrice") || undefined;
  const maxPrice = searchParams.get("maxPrice") || undefined;
  const sortParam = searchParams.get("sort") || "date-desc";
  const pageParam = parseInt(searchParams.get("page") || "1");
  
  // State for results
  const [currentPage, setCurrentPage] = useState(pageParam);
  const [sortBy, setSortBy] = useState(sortParam);
  
  // Parse sort value
  const [sortField, sortOrder] = sortBy.split("-");
  
  // Fetch listings with filters
  const {
    data: listingsData,
    isLoading,
    refetch,
  } = useQuery<{ listings: Listing[]; pagination: any }>({
    queryKey: ['/api/listings', {
      limit: ITEMS_PER_PAGE,
      offset: (currentPage - 1) * ITEMS_PER_PAGE,
      searchTerm: query,
      location: locationParam,
      categoryId: categoryParam ? parseInt(categoryParam) : undefined,
      minPrice: minPrice ? parseInt(minPrice) : undefined,
      maxPrice: maxPrice ? parseInt(maxPrice) : undefined,
      sortBy: sortField,
      sortOrder: sortOrder as 'asc' | 'desc',
    }],
  });
  
  // Update URL when page or sort changes
  useEffect(() => {
    const newParams = new URLSearchParams(searchParams);
    newParams.set("page", currentPage.toString());
    newParams.set("sort", sortBy);
    navigate(`/search?${newParams.toString()}`);
    // We want this effect to run only when these specific values change
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [currentPage, sortBy]);
  
  // Handle sort change
  const handleSortChange = (value: string) => {
    setSortBy(value);
    setCurrentPage(1); // Reset to first page when sort changes
  };
  
  // Handle page change
  const handlePageChange = (page: number) => {
    setCurrentPage(page);
    window.scrollTo(0, 0);
  };
  
  // Total pages
  const totalPages = listingsData?.pagination?.total
    ? Math.ceil(listingsData.pagination.total / ITEMS_PER_PAGE)
    : 1;
  
  // Build title
  let searchTitle = "Résultats de recherche";
  if (query) {
    searchTitle += ` pour "${query}"`;
  }
  if (locationParam) {
    searchTitle += ` à ${locationParam}`;
  }
  if (categoryParam) {
    // We would ideally get the category name here
    searchTitle += ` dans ${categoryParam}`;
  }
  
  return (
    <div className="min-h-screen">
      {/* Search Bar */}
      <SearchBar compact={true} />
      
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        {/* Search Results */}
        <div className="mb-8">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-bold">{searchTitle}</h1>
            
            <div className="flex items-center">
              <span className="mr-2 text-sm">Trier par:</span>
              <Select value={sortBy} onValueChange={handleSortChange}>
                <SelectTrigger className="w-[200px]">
                  <SelectValue placeholder="Trier par" />
                </SelectTrigger>
                <SelectContent>
                  {SORT_OPTIONS.map(option => (
                    <SelectItem key={option.value} value={option.value}>
                      {option.label}
                    </SelectItem>
                  ))}
                </SelectContent>
              </Select>
            </div>
          </div>
          
          <ListingGrid
            listings={listingsData?.listings || []}
            loading={isLoading}
            emptyMessage={
              query || locationParam || categoryParam
                ? "Aucune annonce ne correspond à votre recherche"
                : "Aucune annonce disponible"
            }
          />
          
          {/* Pagination */}
          {!isLoading && listingsData?.pagination?.total > 0 && (
            <Pagination
              currentPage={currentPage}
              totalPages={totalPages}
              onPageChange={handlePageChange}
            />
          )}
        </div>
      </div>
    </div>
  );
};

export default SearchResults;
